==> pyobjc-framework-Cocoa-5.3.tar.gz: pyobjc-framework-Cocoa-5.3/PyObjCTest/test_nsmetadataattributes.py <==
from Foundation import *
from PyObjCTools.TestSupport import *

class TestNSMetaDataAttributes (TestCase):

    @min_os_level('10.7')
    def testConstants10_7(self):
        self.assertIsInstance(NSMetadataItemFSNameKey, unicode)
        self.assertIsInstance(NSMetadataItemDisplayNameKey, unicode)
        self.assertIsInstance(NSMetadataItemURLKey, unicode)
        self.assertIsInstance(NSMetadataItemPathKey, unicode)
        self.assertIsInstance(NSMetadataItemFSSizeKey, unicode)
        self.assertIsInstance(NSMetadataItemFSCreationDateKey, unicode)
        self.assertIsInstance(NSMetadataItemFSContentChangeDateKey, unicode)
        self.assertIsInstance(NSMetadataItemIsUbiquitousKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemHasUnresolvedConflictsKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemIsDownloadedKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemIsDownloadingKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemIsUploadedKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemIsUploadingKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemPercentDownloadedKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemPercentUploadedKey, unicode)

    @min_os_level('10.9')
    def testConstants10_9(self):
        self.assertIsInstance(NSMetadataItemContentTypeKey, unicode)
        self.assertIsInstance(NSMetadataItemContentTypeTreeKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemDownloadingStatusKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemDownloadingStatusDownloaded, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemDownloadingStatusCurrent, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemDownloadingErrorKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemUploadingErrorKey, unicode)
        self.assertIsInstance(NSMetadataItemAttributeChangeDateKey, unicode)
        self.assertIsInstance(NSMetadataItemKeywordsKey, unicode)
        self.assertIsInstance(NSMetadataItemTitleKey, unicode)
        self.assertIsInstance(NSMetadataItemAuthorsKey, unicode)
        self.assertIsInstance(NSMetadataItemEditorsKey, unicode)
        self.assertIsInstance(NSMetadataItemParticipantsKey, unicode)
        self.assertIsInstance(NSMetadataItemProjectsKey, unicode)
        self.assertIsInstance(NSMetadataItemDownloadedDateKey, unicode)
        self.assertIsInstance(NSMetadataItemWhereFromsKey, unicode)
        self.assertIsInstance(NSMetadataItemCommentKey, unicode)
        self.assertIsInstance(NSMetadataItemCopyrightKey, unicode)
        self.assertIsInstance(NSMetadataItemLastUsedDateKey, unicode)
        self.assertIsInstance(NSMetadataItemContentCreationDateKey, unicode)
        self.assertIsInstance(NSMetadataItemContentModificationDateKey, unicode)
        self.assertIsInstance(NSMetadataItemDateAddedKey, unicode)
        self.assertIsInstance(NSMetadataItemDurationSecondsKey, unicode)
        self.assertIsInstance(NSMetadataItemContactKeywordsKey, unicode)
        self.assertIsInstance(NSMetadataItemVersionKey, unicode)
        self.assertIsInstance(NSMetadataItemPixelHeightKey, unicode)
        self.assertIsInstance(NSMetadataItemPixelWidthKey, unicode)
        self.assertIsInstance(NSMetadataItemPixelCountKey, unicode)
        self.assertIsInstance(NSMetadataItemColorSpaceKey, unicode)
        self.assertIsInstance(NSMetadataItemBitsPerSampleKey, unicode)
        self.assertIsInstance(NSMetadataItemFlashOnOffKey, unicode)
        self.assertIsInstance(NSMetadataItemFocalLengthKey, unicode)
        self.assertIsInstance(NSMetadataItemAcquisitionMakeKey, unicode)
        self.assertIsInstance(NSMetadataItemAcquisitionModelKey, unicode)
        self.assertIsInstance(NSMetadataItemISOSpeedKey, unicode)
        self.assertIsInstance(NSMetadataItemOrientationKey, unicode)
        self.assertIsInstance(NSMetadataItemLayerNamesKey, unicode)
        self.assertIsInstance(NSMetadataItemWhiteBalanceKey, unicode)
        self.assertIsInstance(NSMetadataItemApertureKey, unicode)
        self.assertIsInstance(NSMetadataItemProfileNameKey, unicode)
        self.assertIsInstance(NSMetadataItemResolutionWidthDPIKey, unicode)
        self.assertIsInstance(NSMetadataItemResolutionHeightDPIKey, unicode)
        self.assertIsInstance(NSMetadataItemExposureModeKey, unicode)
        self.assertIsInstance(NSMetadataItemExposureTimeSecondsKey, unicode)
        self.assertIsInstance(NSMetadataItemEXIFVersionKey, unicode)
        self.assertIsInstance(NSMetadataItemCameraOwnerKey, unicode)
        self.assertIsInstance(NSMetadataItemFocalLength35mmKey, unicode)
        self.assertIsInstance(NSMetadataItemLensModelKey, unicode)
        self.assertIsInstance(NSMetadataItemEXIFGPSVersionKey, unicode)
        self.assertIsInstance(NSMetadataItemAltitudeKey, unicode)
        self.assertIsInstance(NSMetadataItemLatitudeKey, unicode)
        self.assertIsInstance(NSMetadataItemLongitudeKey, unicode)
        self.assertIsInstance(NSMetadataItemSpeedKey, unicode)
        self.assertIsInstance(NSMetadataItemTimestampKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSTrackKey, unicode)
        self.assertIsInstance(NSMetadataItemImageDirectionKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSStatusKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSMeasureModeKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSDOPKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSMapDatumKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSDestLatitudeKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSDestLongitudeKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSDestBearingKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSProcessingMethodKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSAreaInformationKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSDateStampKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSDifferentalKey, unicode)
        self.assertIsInstance(NSMetadataItemCodecsKey, unicode)
        self.assertIsInstance(NSMetadataItemMediaTypesKey, unicode)
        self.assertIsInstance(NSMetadataItemStreamableKey, unicode)
        self.assertIsInstance(NSMetadataItemTotalBitRateKey, unicode)
        self.assertIsInstance(NSMetadataItemVideoBitRateKey, unicode)
        self.assertIsInstance(NSMetadataItemAudioBitRateKey, unicode)
        self.assertIsInstance(NSMetadataItemDeliveryTypeKey, unicode)
        self.assertIsInstance(NSMetadataItemAlbumKey, unicode)
        self.assertIsInstance(NSMetadataItemHasAlphaChannelKey, unicode)
        self.assertIsInstance(NSMetadataItemRedEyeOnOffKey, unicode)
        self.assertIsInstance(NSMetadataItemMeteringModeKey, unicode)
        self.assertIsInstance(NSMetadataItemMaxApertureKey, unicode)
        self.assertIsInstance(NSMetadataItemFNumberKey, unicode)
        self.assertIsInstance(NSMetadataItemExposureProgramKey, unicode)
        self.assertIsInstance(NSMetadataItemExposureTimeStringKey, unicode)
        self.assertIsInstance(NSMetadataItemHeadlineKey, unicode)
        self.assertIsInstance(NSMetadataItemInstructionsKey, unicode)
        self.assertIsInstance(NSMetadataItemCityKey, unicode)
        self.assertIsInstance(NSMetadataItemStateOrProvinceKey, unicode)
        self.assertIsInstance(NSMetadataItemCountryKey, unicode)
        self.assertIsInstance(NSMetadataItemTextContentKey, unicode)
        self.assertIsInstance(NSMetadataItemAudioSampleRateKey, unicode)
        self.assertIsInstance(NSMetadataItemAudioChannelCountKey, unicode)
        self.assertIsInstance(NSMetadataItemTempoKey, unicode)
        self.assertIsInstance(NSMetadataItemKeySignatureKey, unicode)
        self.assertIsInstance(NSMetadataItemTimeSignatureKey, unicode)
        self.assertIsInstance(NSMetadataItemAudioEncodingApplicationKey, unicode)
        self.assertIsInstance(NSMetadataItemComposerKey, unicode)
        self.assertIsInstance(NSMetadataItemLyricistKey, unicode)
        self.assertIsInstance(NSMetadataItemAudioTrackNumberKey, unicode)
        self.assertIsInstance(NSMetadataItemRecordingDateKey, unicode)
        self.assertIsInstance(NSMetadataItemMusicalGenreKey, unicode)
        self.assertIsInstance(NSMetadataItemIsGeneralMIDISequenceKey, unicode)
        self.assertIsInstance(NSMetadataItemRecordingYearKey, unicode)
        self.assertIsInstance(NSMetadataItemOrganizationsKey, unicode)
        self.assertIsInstance(NSMetadataItemLanguagesKey, unicode)
        self.assertIsInstance(NSMetadataItemRightsKey, unicode)
        self.assertIsInstance(NSMetadataItemPublishersKey, unicode)
        self.assertIsInstance(NSMetadataItemContributorsKey, unicode)
        self.assertIsInstance(NSMetadataItemCoverageKey, unicode)
        self.assertIsInstance(NSMetadataItemSubjectKey, unicode)
        self.assertIsInstance(NSMetadataItemThemeKey, unicode)
        self.assertIsInstance(NSMetadataItemDescriptionKey, unicode)
        self.assertIsInstance(NSMetadataItemIdentifierKey, unicode)
        self.assertIsInstance(NSMetadataItemAudiencesKey, unicode)
        self.assertIsInstance(NSMetadataItemNumberOfPagesKey, unicode)
        self.assertIsInstance(NSMetadataItemPageWidthKey, unicode)
        self.assertIsInstance(NSMetadataItemPageHeightKey, unicode)
        self.assertIsInstance(NSMetadataItemSecurityMethodKey, unicode)
        self.assertIsInstance(NSMetadataItemCreatorKey, unicode)
        self.assertIsInstance(NSMetadataItemEncodingApplicationsKey, unicode)
        self.assertIsInstance(NSMetadataItemDueDateKey, unicode)
        self.assertIsInstance(NSMetadataItemStarRatingKey, unicode)
        self.assertIsInstance(NSMetadataItemPhoneNumbersKey, unicode)
        self.assertIsInstance(NSMetadataItemEmailAddressesKey, unicode)
        self.assertIsInstance(NSMetadataItemInstantMessageAddressesKey, unicode)
        self.assertIsInstance(NSMetadataItemKindKey, unicode)
        self.assertIsInstance(NSMetadataItemRecipientsKey, unicode)
        self.assertIsInstance(NSMetadataItemFinderCommentKey, unicode)
        self.assertIsInstance(NSMetadataItemFontsKey, unicode)
        self.assertIsInstance(NSMetadataItemAppleLoopsRootKeyKey, unicode)
        self.assertIsInstance(NSMetadataItemAppleLoopsKeyFilterTypeKey, unicode)
        self.assertIsInstance(NSMetadataItemAppleLoopsLoopModeKey, unicode)
        self.assertIsInstance(NSMetadataItemAppleLoopDescriptorsKey, unicode)
        self.assertIsInstance(NSMetadataItemMusicalInstrumentCategoryKey, unicode)
        self.assertIsInstance(NSMetadataItemMusicalInstrumentNameKey, unicode)
        self.assertIsInstance(NSMetadataItemCFBundleIdentifierKey, unicode)
        self.assertIsInstance(NSMetadataItemInformationKey, unicode)
        self.assertIsInstance(NSMetadataItemDirectorKey, unicode)
        self.assertIsInstance(NSMetadataItemProducerKey, unicode)
        self.assertIsInstance(NSMetadataItemGenreKey, unicode)
        self.assertIsInstance(NSMetadataItemPerformersKey, unicode)
        self.assertIsInstance(NSMetadataItemOriginalFormatKey, unicode)
        self.assertIsInstance(NSMetadataItemOriginalSourceKey, unicode)
        self.assertIsInstance(NSMetadataItemAuthorEmailAddressesKey, unicode)
        self.assertIsInstance(NSMetadataItemRecipientEmailAddressesKey, unicode)
        self.assertIsInstance(NSMetadataItemAuthorAddressesKey, unicode)
        self.assertIsInstance(NSMetadataItemRecipientAddressesKey, unicode)
        self.assertIsInstance(NSMetadataItemIsLikelyJunkKey, unicode)
        self.assertIsInstance(NSMetadataItemExecutableArchitecturesKey, unicode)
        self.assertIsInstance(NSMetadataItemExecutablePlatformKey, unicode)
        self.assertIsInstance(NSMetadataItemApplicationCategoriesKey, unicode)
        self.assertIsInstance(NSMetadataItemIsApplicationManagedKey, unicode)

    @min_os_level('10.10')
    def testConstants10_10(self):
        self.assertIsInstance(NSMetadataUbiquitousItemDownloadRequestedKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemIsExternalDocumentKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemContainerDisplayNameKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemURLInLocalContainerKey, unicode)

    @min_os_level('10.12')
    def testConstants10_10(self):
        self.assertIsInstance(NSMetadataUbiquitousSharedItemCurrentUserRoleKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousSharedItemCurrentUserPermissionsKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousSharedItemOwnerNameComponentsKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousSharedItemMostRecentEditorNameComponentsKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousSharedItemRoleOwner, unicode)
        self.assertIsInstance(NSMetadataUbiquitousSharedItemRoleParticipant, unicode)
        self.assertIsInstance(NSMetadataUbiquitousSharedItemPermissionsReadOnly, unicode)
        self.assertIsInstance(NSMetadataUbiquitousSharedItemPermissionsReadWrite, unicode)

if __name__ == "__main__":
    main()

==> pyobjc-framework-Cocoa-6.1.tar.gz: pyobjc-framework-Cocoa-6.1/PyObjCTest/test_nsmetadataattributes.py <==
from Foundation import *
from PyObjCTools.TestSupport import *


class TestNSMetaDataAttributes(TestCase):
    @min_os_level("10.7")
    def testConstants10_7(self):
        self.assertIsInstance(NSMetadataItemFSNameKey, unicode)
        self.assertIsInstance(NSMetadataItemDisplayNameKey, unicode)
        self.assertIsInstance(NSMetadataItemURLKey, unicode)
        self.assertIsInstance(NSMetadataItemPathKey, unicode)
        self.assertIsInstance(NSMetadataItemFSSizeKey, unicode)
        self.assertIsInstance(NSMetadataItemFSCreationDateKey, unicode)
        self.assertIsInstance(NSMetadataItemFSContentChangeDateKey, unicode)
        self.assertIsInstance(NSMetadataItemIsUbiquitousKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemHasUnresolvedConflictsKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemIsDownloadedKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemIsDownloadingKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemIsUploadedKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemIsUploadingKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemPercentDownloadedKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemPercentUploadedKey, unicode)

    @min_os_level("10.9")
    def testConstants10_9(self):
        self.assertIsInstance(NSMetadataItemContentTypeKey, unicode)
        self.assertIsInstance(NSMetadataItemContentTypeTreeKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemDownloadingStatusKey, unicode)
        self.assertIsInstance(
            NSMetadataUbiquitousItemDownloadingStatusDownloaded, unicode
        )
        self.assertIsInstance(NSMetadataUbiquitousItemDownloadingStatusCurrent, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemDownloadingErrorKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemUploadingErrorKey, unicode)
        self.assertIsInstance(NSMetadataItemAttributeChangeDateKey, unicode)
        self.assertIsInstance(NSMetadataItemKeywordsKey, unicode)
        self.assertIsInstance(NSMetadataItemTitleKey, unicode)
        self.assertIsInstance(NSMetadataItemAuthorsKey, unicode)
        self.assertIsInstance(NSMetadataItemEditorsKey, unicode)
        self.assertIsInstance(NSMetadataItemParticipantsKey, unicode)
        self.assertIsInstance(NSMetadataItemProjectsKey, unicode)
        self.assertIsInstance(NSMetadataItemDownloadedDateKey, unicode)
        self.assertIsInstance(NSMetadataItemWhereFromsKey, unicode)
        self.assertIsInstance(NSMetadataItemCommentKey, unicode)
        self.assertIsInstance(NSMetadataItemCopyrightKey, unicode)
        self.assertIsInstance(NSMetadataItemLastUsedDateKey, unicode)
        self.assertIsInstance(NSMetadataItemContentCreationDateKey, unicode)
        self.assertIsInstance(NSMetadataItemContentModificationDateKey, unicode)
        self.assertIsInstance(NSMetadataItemDateAddedKey, unicode)
        self.assertIsInstance(NSMetadataItemDurationSecondsKey, unicode)
        self.assertIsInstance(NSMetadataItemContactKeywordsKey, unicode)
        self.assertIsInstance(NSMetadataItemVersionKey, unicode)
        self.assertIsInstance(NSMetadataItemPixelHeightKey, unicode)
        self.assertIsInstance(NSMetadataItemPixelWidthKey, unicode)
        self.assertIsInstance(NSMetadataItemPixelCountKey, unicode)
        self.assertIsInstance(NSMetadataItemColorSpaceKey, unicode)
        self.assertIsInstance(NSMetadataItemBitsPerSampleKey, unicode)
        self.assertIsInstance(NSMetadataItemFlashOnOffKey, unicode)
        self.assertIsInstance(NSMetadataItemFocalLengthKey, unicode)
        self.assertIsInstance(NSMetadataItemAcquisitionMakeKey, unicode)
        self.assertIsInstance(NSMetadataItemAcquisitionModelKey, unicode)
        self.assertIsInstance(NSMetadataItemISOSpeedKey, unicode)
        self.assertIsInstance(NSMetadataItemOrientationKey, unicode)
        self.assertIsInstance(NSMetadataItemLayerNamesKey, unicode)
        self.assertIsInstance(NSMetadataItemWhiteBalanceKey, unicode)
        self.assertIsInstance(NSMetadataItemApertureKey, unicode)
        self.assertIsInstance(NSMetadataItemProfileNameKey, unicode)
        self.assertIsInstance(NSMetadataItemResolutionWidthDPIKey, unicode)
        self.assertIsInstance(NSMetadataItemResolutionHeightDPIKey, unicode)
        self.assertIsInstance(NSMetadataItemExposureModeKey, unicode)
        self.assertIsInstance(NSMetadataItemExposureTimeSecondsKey, unicode)
        self.assertIsInstance(NSMetadataItemEXIFVersionKey, unicode)
        self.assertIsInstance(NSMetadataItemCameraOwnerKey, unicode)
        self.assertIsInstance(NSMetadataItemFocalLength35mmKey, unicode)
        self.assertIsInstance(NSMetadataItemLensModelKey, unicode)
        self.assertIsInstance(NSMetadataItemEXIFGPSVersionKey, unicode)
        self.assertIsInstance(NSMetadataItemAltitudeKey, unicode)
        self.assertIsInstance(NSMetadataItemLatitudeKey, unicode)
        self.assertIsInstance(NSMetadataItemLongitudeKey, unicode)
        self.assertIsInstance(NSMetadataItemSpeedKey, unicode)
        self.assertIsInstance(NSMetadataItemTimestampKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSTrackKey, unicode)
        self.assertIsInstance(NSMetadataItemImageDirectionKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSStatusKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSMeasureModeKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSDOPKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSMapDatumKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSDestLatitudeKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSDestLongitudeKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSDestBearingKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSProcessingMethodKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSAreaInformationKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSDateStampKey, unicode)
        self.assertIsInstance(NSMetadataItemGPSDifferentalKey, unicode)
        self.assertIsInstance(NSMetadataItemCodecsKey, unicode)
        self.assertIsInstance(NSMetadataItemMediaTypesKey, unicode)
        self.assertIsInstance(NSMetadataItemStreamableKey, unicode)
        self.assertIsInstance(NSMetadataItemTotalBitRateKey, unicode)
        self.assertIsInstance(NSMetadataItemVideoBitRateKey, unicode)
        self.assertIsInstance(NSMetadataItemAudioBitRateKey, unicode)
        self.assertIsInstance(NSMetadataItemDeliveryTypeKey, unicode)
        self.assertIsInstance(NSMetadataItemAlbumKey, unicode)
        self.assertIsInstance(NSMetadataItemHasAlphaChannelKey, unicode)
        self.assertIsInstance(NSMetadataItemRedEyeOnOffKey, unicode)
        self.assertIsInstance(NSMetadataItemMeteringModeKey, unicode)
        self.assertIsInstance(NSMetadataItemMaxApertureKey, unicode)
        self.assertIsInstance(NSMetadataItemFNumberKey, unicode)
        self.assertIsInstance(NSMetadataItemExposureProgramKey, unicode)
        self.assertIsInstance(NSMetadataItemExposureTimeStringKey, unicode)
        self.assertIsInstance(NSMetadataItemHeadlineKey, unicode)
        self.assertIsInstance(NSMetadataItemInstructionsKey, unicode)
        self.assertIsInstance(NSMetadataItemCityKey, unicode)
        self.assertIsInstance(NSMetadataItemStateOrProvinceKey, unicode)
        self.assertIsInstance(NSMetadataItemCountryKey, unicode)
        self.assertIsInstance(NSMetadataItemTextContentKey, unicode)
        self.assertIsInstance(NSMetadataItemAudioSampleRateKey, unicode)
        self.assertIsInstance(NSMetadataItemAudioChannelCountKey, unicode)
        self.assertIsInstance(NSMetadataItemTempoKey, unicode)
        self.assertIsInstance(NSMetadataItemKeySignatureKey, unicode)
        self.assertIsInstance(NSMetadataItemTimeSignatureKey, unicode)
        self.assertIsInstance(NSMetadataItemAudioEncodingApplicationKey, unicode)
        self.assertIsInstance(NSMetadataItemComposerKey, unicode)
        self.assertIsInstance(NSMetadataItemLyricistKey, unicode)
        self.assertIsInstance(NSMetadataItemAudioTrackNumberKey, unicode)
        self.assertIsInstance(NSMetadataItemRecordingDateKey, unicode)
        self.assertIsInstance(NSMetadataItemMusicalGenreKey, unicode)
        self.assertIsInstance(NSMetadataItemIsGeneralMIDISequenceKey, unicode)
        self.assertIsInstance(NSMetadataItemRecordingYearKey, unicode)
        self.assertIsInstance(NSMetadataItemOrganizationsKey, unicode)
        self.assertIsInstance(NSMetadataItemLanguagesKey, unicode)
        self.assertIsInstance(NSMetadataItemRightsKey, unicode)
        self.assertIsInstance(NSMetadataItemPublishersKey, unicode)
        self.assertIsInstance(NSMetadataItemContributorsKey, unicode)
        self.assertIsInstance(NSMetadataItemCoverageKey, unicode)
        self.assertIsInstance(NSMetadataItemSubjectKey, unicode)
        self.assertIsInstance(NSMetadataItemThemeKey, unicode)
        self.assertIsInstance(NSMetadataItemDescriptionKey, unicode)
        self.assertIsInstance(NSMetadataItemIdentifierKey, unicode)
        self.assertIsInstance(NSMetadataItemAudiencesKey, unicode)
        self.assertIsInstance(NSMetadataItemNumberOfPagesKey, unicode)
        self.assertIsInstance(NSMetadataItemPageWidthKey, unicode)
        self.assertIsInstance(NSMetadataItemPageHeightKey, unicode)
        self.assertIsInstance(NSMetadataItemSecurityMethodKey, unicode)
        self.assertIsInstance(NSMetadataItemCreatorKey, unicode)
        self.assertIsInstance(NSMetadataItemEncodingApplicationsKey, unicode)
        self.assertIsInstance(NSMetadataItemDueDateKey, unicode)
        self.assertIsInstance(NSMetadataItemStarRatingKey, unicode)
        self.assertIsInstance(NSMetadataItemPhoneNumbersKey, unicode)
        self.assertIsInstance(NSMetadataItemEmailAddressesKey, unicode)
        self.assertIsInstance(NSMetadataItemInstantMessageAddressesKey, unicode)
        self.assertIsInstance(NSMetadataItemKindKey, unicode)
        self.assertIsInstance(NSMetadataItemRecipientsKey, unicode)
        self.assertIsInstance(NSMetadataItemFinderCommentKey, unicode)
        self.assertIsInstance(NSMetadataItemFontsKey, unicode)
        self.assertIsInstance(NSMetadataItemAppleLoopsRootKeyKey, unicode)
        self.assertIsInstance(NSMetadataItemAppleLoopsKeyFilterTypeKey, unicode)
        self.assertIsInstance(NSMetadataItemAppleLoopsLoopModeKey, unicode)
        self.assertIsInstance(NSMetadataItemAppleLoopDescriptorsKey, unicode)
        self.assertIsInstance(NSMetadataItemMusicalInstrumentCategoryKey, unicode)
        self.assertIsInstance(NSMetadataItemMusicalInstrumentNameKey, unicode)
        self.assertIsInstance(NSMetadataItemCFBundleIdentifierKey, unicode)
        self.assertIsInstance(NSMetadataItemInformationKey, unicode)
        self.assertIsInstance(NSMetadataItemDirectorKey, unicode)
        self.assertIsInstance(NSMetadataItemProducerKey, unicode)
        self.assertIsInstance(NSMetadataItemGenreKey, unicode)
        self.assertIsInstance(NSMetadataItemPerformersKey, unicode)
        self.assertIsInstance(NSMetadataItemOriginalFormatKey, unicode)
        self.assertIsInstance(NSMetadataItemOriginalSourceKey, unicode)
        self.assertIsInstance(NSMetadataItemAuthorEmailAddressesKey, unicode)
        self.assertIsInstance(NSMetadataItemRecipientEmailAddressesKey, unicode)
        self.assertIsInstance(NSMetadataItemAuthorAddressesKey, unicode)
        self.assertIsInstance(NSMetadataItemRecipientAddressesKey, unicode)
        self.assertIsInstance(NSMetadataItemIsLikelyJunkKey, unicode)
        self.assertIsInstance(NSMetadataItemExecutableArchitecturesKey, unicode)
        self.assertIsInstance(NSMetadataItemExecutablePlatformKey, unicode)
        self.assertIsInstance(NSMetadataItemApplicationCategoriesKey, unicode)
        self.assertIsInstance(NSMetadataItemIsApplicationManagedKey, unicode)

    @min_os_level("10.10")
    def testConstants10_10(self):
        self.assertIsInstance(NSMetadataUbiquitousItemDownloadRequestedKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemIsExternalDocumentKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemContainerDisplayNameKey, unicode)
        self.assertIsInstance(NSMetadataUbiquitousItemURLInLocalContainerKey, unicode)

    @min_os_level("10.12")
    def testConstants10_10(self):
        self.assertIsInstance(NSMetadataUbiquitousSharedItemCurrentUserRoleKey, unicode)
        self.assertIsInstance(
            NSMetadataUbiquitousSharedItemCurrentUserPermissionsKey, unicode
        )
        self.assertIsInstance(
            NSMetadataUbiquitousSharedItemOwnerNameComponentsKey, unicode
        )
        self.assertIsInstance(
            NSMetadataUbiquitousSharedItemMostRecentEditorNameComponentsKey, unicode
        )
        self.assertIsInstance(NSMetadataUbiquitousSharedItemRoleOwner, unicode)
        self.assertIsInstance(NSMetadataUbiquitousSharedItemRoleParticipant, unicode)
        self.assertIsInstance(NSMetadataUbiquitousSharedItemPermissionsReadOnly, unicode)
        self.assertIsInstance(NSMetadataUbiquitousSharedItemPermissionsReadWrite, unicode)


if __name__ == "__main__":
    main()
